pub enum UnitType {
Army,
Fleet,
}Expand description
The type of a military unit. Armies are convoyable land-based units; fleets are sea-going units which are able to convoy armies.
Variants
Army
A convoyable land-based unit which can traverse inland and coastal terrain.
Fleet
A sea-based unit which can traverse sea and coastal terrain.